Event
=====

``Event`` provides simple python tools that allow your application components to communicate with each other by dispatching events and listening to them.

.. image:: https://travis-ci.org/python-edgy/event.svg?branch=master
    :target: https://travis-ci.org/python-edgy/event

.. image:: https://readthedocs.org/projects/edgyevent/badge/?version=latest
    :target: http://edgyevent.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status

Install
:::::::

.. code-block:: shell

   pip install edgy.event


